# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .extracted_series_dto import ExtractedSeriesDto
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class PlotParserOutputV2Dto(UniversalBaseModel):
    """
    New plot parser output for v2, will replace old PlotParserOutput
    """

    extracted_series: typing.List[ExtractedSeriesDto]
    origin: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    x_axis_len: typing.Optional[float] = None
    y_axis_len: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
