# This file was auto-generated by Fern from our API Definition.

import typing

StatementType = typing.Union[
    typing.Literal["COST_FUNCTION", "PARAMETER_CONSTRAINT", "UNFORMALIZABLE_STATEMENT"], typing.Any
]
