# This file was auto-generated by Fern from our API Definition.

import typing
from ....types.plot_parser_output import PlotParserOutput
from ....types.plot_parser_output_v2dto import PlotParserOutputV2Dto

PlotPointsResponse = typing.Union[PlotParserOutput, PlotParserOutputV2Dto]
